# Plugins

## Usage

## API

::: whatrecord.plugins.happi
::: whatrecord.plugins.netconfig
::: whatrecord.plugins.util

### whatrecord.plugins.gdb_binary_info

A GDB script to get useful information out of IOC binaries.
